# -*- coding: utf-8 -*-

from rest_framework import serializers
from thx.api.serializers import ThuxCreateSerializerMixin, ThuxUpdateSerializerMixin

from ... import models
from apps.role.core.serializers import ThuxRoleSerializerMixin


# ADDRESS SCOPE
class AddressScopeSerializer(ThuxRoleSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_address_address_scope'
        model = models.AddressScope
        fields = '__all__'


class AddressScopeCreateSerializer(
    ThuxRoleSerializerMixin, ThuxCreateSerializerMixin, serializers.ModelSerializer
):

    def to_representation(self, instance):
        return AddressScopeSerializer(instance, context=self.context).data

    class Meta:
        ref_name = 'v1_address_address_scope_create'
        model = models.AddressScope
        fields = '__all__'


class AddressScopeUpdateSerializer(
    ThuxRoleSerializerMixin, ThuxUpdateSerializerMixin, serializers.ModelSerializer
):

    def to_representation(self, instance):
        return AddressScopeSerializer(instance, context=self.context).data

    class Meta:
        ref_name = 'v1_address_address_scope_update'
        model = models.AddressScope
        fields = '__all__'


class AddressScopeEnableSerializer(ThuxRoleSerializerMixin, serializers.ModelSerializer):

    def update(self, instance, validated_data):
        instance.status = 1
        instance.save()
        return instance

    class Meta:
        ref_name = 'v1_address_address_scope_enable'
        model = models.AddressScope
        fields = '__all__'

    def to_representation(self, instance):
        return AddressScopeSerializer(instance, context=self.context).data


class AddressScopeDisableSerializer(ThuxRoleSerializerMixin, serializers.ModelSerializer):

    def update(self, instance, validated_data):
        instance.status = 0
        instance.save()
        return instance

    class Meta:
        ref_name = 'v1_address_address_scope_disable'
        model = models.AddressScope
        fields = '__all__'

    def to_representation(self, instance):
        return AddressScopeSerializer(instance, context=self.context).data

